@@ -1,9 +1,9 @@
 `table.freq` <-
-function(histogram){
-xx<-histogram$mids
-yy<-histogram$counts
+function(object){
+xx<-object$mids
+yy<-object$counts
 y1<-sum(yy)
-zz<-histogram$breaks
+zz<-object$breaks
 x<-length(xx)
 acum<-0
 z<-rep(0,7*x)
